from click.testing import CliRunner

from galaxy_update.__main__ import cli

REQUIREMENTS_YML = """---
collections:
  - name: ansible.utils
    version: 1.0.0
"""

API_RESPONSE = {
    "meta": {"count": 58},
    "links": {},
    "data": [
        {
            "version": "6.0.0",
            "href": "/api/v3/plugin/ansible/content/published/collections/index/ansible/utils/versions/6.0.0/",
            "created_at": "2025-04-14T06:20:22.435485Z",
            "updated_at": "2025-04-14T06:20:22.587797Z",
            "requires_ansible": ">=2.16.0",
            "marks": [],
        },
    ],
}


def test_cli_updates_version(tmp_path, mocker):
    req_path = tmp_path / "requirements.yml"
    req_path.write_text(REQUIREMENTS_YML)

    mock_response = mocker.Mock()
    mock_response.raise_for_status.return_value = None
    mock_response.json.return_value = API_RESPONSE
    mocker.patch("httpx.AsyncClient.get", return_value=mock_response)

    runner = CliRunner()
    result = runner.invoke(cli, [str(req_path)])
    assert result.exit_code == 0
    out = req_path.read_text()
    assert "version: 6.0.0" in out



"""Update dependencies in requirements.yml."""

import asyncio
from pathlib import Path

import click
import httpx
import pyaml
import yaml


@click.command()
@click.argument(
    "requirements",
    nargs=-1,
    required=True,
    type=click.Path(exists=True, dir_okay=False, path_type=Path),
)
@click.version_option()
def cli(requirements: tuple[Path]) -> None:
    """Update dependencies in requirements.yml."""
    asyncio.run(update_requirements(requirements))


async def update_requirements(requirements: tuple[Path]) -> None:
    """Update dependencies in requirements.yml."""
    # Create a HTTP client
    async with httpx.AsyncClient() as client:
        base_url = "https://galaxy.ansible.com/api"
        collections_index = "v3/plugin/ansible/content/published/collections/index"

        for requirements_file in requirements:
            # Load the requirements file
            reqs = yaml.safe_load(requirements_file.read_text())

            # Update the versions
            for collection in reqs["collections"]:
                name = collection["name"].replace(".", "/")
                response = await client.get(f"{base_url}/{collections_index}/{name}/versions/")
                response.raise_for_status()
                collection["version"] = response.json()["data"][0]["version"]

            # Write the updated requirements back to the file
            updated = pyaml.dump(reqs, explicit_start=True)
            requirements_file.write_text(str(updated))
